@@ -2,6 +2,7 @@
 // Alacritty is licensed under Apache 2.0 license.
 // https://github.com/alacritty/alacritty/pull/4763/files
 
+use crate::ansi::sixel;
 use crate::config::colors::ColorRgb;
 use crate::crosswords::grid::Dimensions;
 use crate::sugarloaf::{GraphicData, GraphicId};
@@ -22,6 +23,7 @@ pub struct ClearSubregion {
     pub y: u16,
 }
 
+#[derive(Debug, Clone)]
 pub struct UpdateQueues {
     /// Graphics read from the PTY.
     pub pending: Vec<GraphicData>,
@@ -33,9 +35,6 @@ pub struct UpdateQueues {
     pub clear_subregions: Vec<ClearSubregion>,
 }
 
-/// Max allowed dimensions (width, height) for the graphic, in pixels.
-pub const MAX_GRAPHIC_DIMENSIONS: [usize; 2] = [4096, 4096];
-
 #[derive(Clone, Debug)]
 pub struct TextureRef {
     /// Graphic identifier.
@@ -127,7 +126,7 @@ pub enum TextureOperation {
 }
 
 /// Track changes in the grid to add or to remove graphics.
-#[derive(Clone, Debug, Default)]
+#[derive(Debug, Default)]
 pub struct Graphics {
     /// Last generated identifier.
     pub last_id: u64,
@@ -146,6 +145,9 @@ pub struct Graphics {
 
     /// Cell width in pixels.
     pub cell_width: f32,
+
+    /// Current Sixel parser.
+    pub sixel_parser: Option<Box<sixel::Parser>>,
 }
 
 impl Graphics {
@@ -166,6 +168,10 @@ impl Graphics {
     /// Get queues to update graphics in the grid.
     ///
     /// If all queues are empty, it returns `None`.
+    pub fn has_pending_updates(&self) -> bool {
+        !self.pending.is_empty() || !self.texture_operations.lock().is_empty()
+    }
+
     pub fn take_queues(&mut self) -> Option<UpdateQueues> {
         let texture_operations = {
             let mut queue = self.texture_operations.lock();
@@ -214,6 +220,7 @@ fn check_opaque_region() {
         color_type: ColorType::Rgb,
         pixels: vec![255; 10 * 10 * 3],
         is_opaque: true,
+        resize: None,
     };
 
     assert!(graphic.is_filled(1, 1, 3, 3));
@@ -236,6 +243,7 @@ fn check_opaque_region() {
         height: 10,
         color_type: ColorType::Rgba,
         is_opaque: false,
+        resize: None,
     };
 
     assert!(graphic.is_filled(0, 0, 3, 3));
